# ExternalAPITransportOrderRowRawData


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**assortment_id** | **int** |  | [readonly] 

## Example

```python
from openapi_client.models.external_api_transport_order_row_raw_data import ExternalAPITransportOrderRowRawData

# TODO update the JSON string below
json = "{}"
# create an instance of ExternalAPITransportOrderRowRawData from a JSON string
external_api_transport_order_row_raw_data_instance = ExternalAPITransportOrderRowRawData.from_json(json)
# print the JSON string representation of the object
print(ExternalAPITransportOrderRowRawData.to_json())

# convert the object into a dict
external_api_transport_order_row_raw_data_dict = external_api_transport_order_row_raw_data_instance.to_dict()
# create an instance of ExternalAPITransportOrderRowRawData from a dict
external_api_transport_order_row_raw_data_from_dict = ExternalAPITransportOrderRowRawData.from_dict(external_api_transport_order_row_raw_data_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


